searchData={"items":[{"type":"task","title":"mix x509.gen.selfsigned","doc":"Generates a self-signed certificate for testing.\n\n    mix x509.gen.selfsigned\n    mix x509.gen.selfsigned my-app my-app.local my-app.internal.example.com\n\nCreates a private key and a self-signed certificate in PEM format. These\nfiles can be referenced in the `certfile` and `keyfile` parameters of an\n`:ssl` server.\n\nWARNING: only use the generated certificate for testing in a closed network\nenvironment, such as running a development server on `localhost`.\nFor production, staging, or testing servers on the public internet, obtain a\nproper certificate, for example from [Let's Encrypt](https://letsencrypt.org).\n\nNOTE: when using Google Chrome, open chrome://flags/#allow-insecure-localhost\nto enable the use of self-signed certificates on `localhost`.","ref":"Mix.Tasks.X509.Gen.Selfsigned.html"},{"type":"task","title":"Arguments - mix x509.gen.selfsigned","doc":"The list of hostnames, if none are specified, defaults to:\n\n  * localhost\n\nOther (optional) arguments:\n\n  * `--output` (`-o`): the path and base filename for the certificate and\n    key (default: priv/cert/selfsigned)\n  * `--name` (`-n`): the Common Name value in certificate's subject\n    (default: \"Self-signed test certificate\")\n    * `--force` (`-f`): overwrite existing files without prompting for\n      confirmation\n\nRequires OTP 20 or later.","ref":"Mix.Tasks.X509.Gen.Selfsigned.html#module-arguments"},{"type":"task","title":"mix x509.gen.suite","doc":"Generates a suite of test certificates.\n\n    mix x509.gen.suite\n    mix x509.gen.suite test.local\n\nPlease refer to the documentation for `X509.Test.Suite` for information about\nthe scenarios that may be tested using the generated certificates.\n\nWARNING: only use the generated certificates for testing in a closed network\nenvironment, such as running a development server on `localhost`.\nFor production, staging, or testing servers on the public internet, obtain a\nproper certificate, for example from [Let's Encrypt](https://letsencrypt.org).","ref":"Mix.Tasks.X509.Gen.Suite.html"},{"type":"task","title":"Arguments - mix x509.gen.suite","doc":"This tasks takes a single, optional argument: the domain name to use in the\nhostnames embedded in the certificates. If no domain name is specified, the\ndefault domain from `X509.Test.Suite` will be used.\n\nOther (optional) arguments:\n\n  * '--password' ('-p'): if set, an encrypted, password protected version of\n    each private key will be created\n  * `--crlserver` (`-c`): the base URL for the CRL server to be used for\n    CRL distribution points\n  * `--output` (`-o`): the path where the certificates and keys should be\n    stored (default: priv/cert/suite)\n  * `--force` (`-f`): overwrite existing files without prompting for\n    confirmation\n\nRequires OTP 20 or later.","ref":"Mix.Tasks.X509.Gen.Suite.html#module-arguments"},{"type":"task","title":"mix x509.test_server","doc":"Runs a server for manual TLS client testing\n\n    mix x509.test_server\n    mix x509.test_server test.local\n\nPlease refer to the documentation for `X509.Test.Suite` for information about\nthe scenarios that may be tested using the server.\n\nRequires OTP 20 or later.","ref":"Mix.Tasks.X509.TestServer.html"},{"type":"module","title":"X509","doc":"Generic functions for working with X.509 entities.","ref":"X509.html"},{"type":"function","title":"X509.from_pem/2","doc":"Scans the given string for PEM encoded entities.\n\nAn optional list of data types may be specified to filter the result down\nto entries of the given types. If an empty list is specified (the default),\nthe result is not filtered.","ref":"X509.html#from_pem/2"},{"type":"module","title":"X509.CRL","doc":"Module for generating and parsing Certificate Revocation Lists (CRLs).\n\nThe corresponding ASN.1 data type, used in Erlang's `:public_key` module, is\ncalled `:CertificateList`.\n\nPlease note that maintaining a CRL typically requires keeping state: the list\nof revoked certificates, along with their revocation date and expiry date\n(when they can be removed from the CRL), as well as the CRLs sequence number\nand the date/time of the next update. This module offers a purely functional\ninterface for generating CRLs based on state kept by the caller.\n\nDelta CRLs are not currently supported.","ref":"X509.CRL.html"},{"type":"function","title":"X509.CRL.extension/2","doc":"Looks up the value of a specific extension in a CRL.\n\nThe desired extension can be specified as an atom or an OID value. Returns\n`nil` if the specified extension is not present in the CRL.","ref":"X509.CRL.html#extension/2"},{"type":"function","title":"X509.CRL.extensions/1","doc":"Returns the list of extensions included in a CRL.","ref":"X509.CRL.html#extensions/1"},{"type":"function","title":"X509.CRL.from_der/1","doc":"Parses a CRL in DER (binary) format.\n\nReturns an `:ok` tuple in case of success, or an `:error` tuple in case of\nfailure. Possible error reasons are:\n\n  * `:malformed` - the data could not be decoded as a CRL","ref":"X509.CRL.html#from_der/1"},{"type":"function","title":"X509.CRL.from_der!/1","doc":"Attempts to parse a CRL in DER (binary) format. Raises in case of failure.","ref":"X509.CRL.html#from_der!/1"},{"type":"function","title":"X509.CRL.from_pem/1","doc":"Parses a CRL in PEM format.\n\nProcesses the first PEM entry of type X509 CRL found in the input. Returns an\n`:ok` tuple in case of success, or an `:error` tuple in case of failure.\nPossible error reasons are:\n\n  * `:not_found` - no PEM entry of type X509 CRL was found\n  * `:malformed` - the entry could not be decoded as a CRL","ref":"X509.CRL.html#from_pem/1"},{"type":"function","title":"X509.CRL.from_pem!/1","doc":"Attempts to parse a CRL in PEM format. Raises in case of failure.\n\nProcesses the first PEM entry of type X509 CRL found in the input.","ref":"X509.CRL.html#from_pem!/1"},{"type":"function","title":"X509.CRL.issuer/1","doc":"Returns the Issuer field of the CRL.","ref":"X509.CRL.html#issuer/1"},{"type":"function","title":"X509.CRL.list/1","doc":"Returns the list of CRL entries included in a CRL.","ref":"X509.CRL.html#list/1"},{"type":"function","title":"X509.CRL.new/4","doc":"Returns a new `:CertificateList` record for the specified CRL entries.\n\nThe first argument is a, possibly empty, list of CRL entries. Use\n`X509.CRL.Entry.new/3` to create a CRL entry for a given certificate.\n\nThe second and third argument are the issuing certificate and the associated\nprivate key. The certificate must include the `:cRLSign` key usage.","ref":"X509.CRL.html#new/4"},{"type":"function","title":"Options: - X509.CRL.new/4","doc":"* `:hash` - the hashing algorithm to use when signing the CRL (default:\n  `:sha256`)\n* `:this_update` - a `DateTime` struct specifying the timestamp of the CRL\n  update (default: the current time)\n* `:next_update` - a `DateTime` struct specifying the timestamp of next\n  scheduled CRL update (default: see `:next_update_in_days`)\n* `:next_update_in_days` - if no `:next_update` timestamp is specified, this\n  parameter defines the number of days in the future the next CRL update is\n  expected (default: 30)\n* `:extensions` - a keyword list of extension names and values; by default\n  the `authority_key_identifier` extension will be included, with a value\n  derived from the issuer's `subject_key_identifier` (if present); to disable\n  this extension, specify `authority_key_identifier: false`; other extension\n  values will be included in the CRL as-is","ref":"X509.CRL.html#new/4-options"},{"type":"function","title":"X509.CRL.next_update/1","doc":"Returns the date and time when the next CRL update is expected.","ref":"X509.CRL.html#next_update/1"},{"type":"opaque","title":"X509.CRL.t/0","doc":"`:CertificateList` record, as used in Erlang's `:public_key` module","ref":"X509.CRL.html#t:t/0"},{"type":"function","title":"X509.CRL.this_update/1","doc":"Returns the date and time when the CRL was issued.","ref":"X509.CRL.html#this_update/1"},{"type":"function","title":"X509.CRL.to_der/1","doc":"Converts a CRL to DER (binary) format.","ref":"X509.CRL.html#to_der/1"},{"type":"function","title":"X509.CRL.to_pem/1","doc":"Converts a CRL to PEM format.","ref":"X509.CRL.html#to_pem/1"},{"type":"function","title":"X509.CRL.valid?/2","doc":"Verifies whether a CRL matches the given issuer certificate and has a valid\nsignature.","ref":"X509.CRL.html#valid?/2"},{"type":"module","title":"X509.CRL.Entry","doc":"CRL entries identify revoked certificates and contain metadata about the\nrevocation.","ref":"X509.CRL.Entry.html"},{"type":"function","title":"X509.CRL.Entry.extension/2","doc":"Looks up a specific extension in a CRL entry.\n\nThe desired extension can be specified as an atom or an OID value. Returns\n`nil` if the specified extension is not present in the CRL entry.","ref":"X509.CRL.Entry.html#extension/2"},{"type":"function","title":"X509.CRL.Entry.extensions/1","doc":"Returns the list of extensions in a CRL entry.","ref":"X509.CRL.Entry.html#extensions/1"},{"type":"function","title":"X509.CRL.Entry.new/3","doc":"Returns a new CRL entry for the given certificate or serial number. The\nrevocation date must be specified, and additional metadata may be specified\nas one or more `X509.CRL.Extension` entries.","ref":"X509.CRL.Entry.html#new/3"},{"type":"function","title":"X509.CRL.Entry.revocation_date/1","doc":"Returns the certificate recocation date for a CRL entry.","ref":"X509.CRL.Entry.html#revocation_date/1"},{"type":"function","title":"X509.CRL.Entry.serial/1","doc":"Returns the certificate serial number for a CRL entry.","ref":"X509.CRL.Entry.html#serial/1"},{"type":"opaque","title":"X509.CRL.Entry.t/0","doc":"`:TBSCertList_revokedCertificates_SEQOF` record, as used in Erlang's\n`:public_key` module","ref":"X509.CRL.Entry.html#t:t/0"},{"type":"module","title":"X509.CRL.Extension","doc":"Convenience functions for creating `:Extension` records for use in\nCRLs or CRL entries.\n\nSome extensions defined in `X509.Certificate.Extension` may also be used\nin CRLs (e.g. `authority_key_identifier`). Please use the functions in\nthat module to create such extension records.","ref":"X509.CRL.Extension.html"},{"type":"function","title":"X509.CRL.Extension.crl_number/1","doc":"The CRL number conveys a monotonically increasing sequence number for a\ngiven CRL scope and CRL issuer. This extension allows users to easily\ndetermine when a particular CRL supersedes another CRL.\n\nThis extension is marked as non-critical.\n\nExample:\n\n    iex> X509.CRL.Extension.crl_number(12)\n    {:Extension, {2, 5, 29, 20}, false, <<2, 1, 12>>}","ref":"X509.CRL.Extension.html#crl_number/1"},{"type":"type","title":"X509.CRL.Extension.extension_id/0","doc":"","ref":"X509.CRL.Extension.html#t:extension_id/0"},{"type":"function","title":"X509.CRL.Extension.find/2","doc":"Looks up the value of a specific extension in a list.\n\nThe desired extension can be specified as an atom or an OID value. Returns\n`nil` if the specified extension is not present in the certificate.","ref":"X509.CRL.Extension.html#find/2"},{"type":"function","title":"X509.CRL.Extension.reason_code/1","doc":"The reason code identifies the reason for the certificate revocation.\nCRL issuers are strongly encouraged to include meaningful reason codes\nin CRL entries.\n\nThe value `:removeFromCRL` is reserved for use in delta CRLs.\n\nThis extension is marked as non-critical.\n\nExample:\n\n    iex> X509.CRL.Extension.reason_code(:keyCompromise)\n    {:Extension, {2, 5, 29, 21}, false, <<10, 1, 1>>}","ref":"X509.CRL.Extension.html#reason_code/1"},{"type":"type","title":"X509.CRL.Extension.reason_code_value/0","doc":"Supported values in the reason code extension","ref":"X509.CRL.Extension.html#t:reason_code_value/0"},{"type":"opaque","title":"X509.CRL.Extension.t/0","doc":"`:Extension` record, as used in Erlang's `:public_key` module","ref":"X509.CRL.Extension.html#t:t/0"},{"type":"module","title":"X509.CSR","doc":"Implements PKCS#10 Certificate Signing Requests (CSRs), formally known by\ntheir ASN.1 type CertificationRequest.","ref":"X509.CSR.html"},{"type":"function","title":"X509.CSR.extension_request/1","doc":"Returns the certificate extensions from the `extensionRequest` attribute.","ref":"X509.CSR.html#extension_request/1"},{"type":"function","title":"X509.CSR.from_der/1","doc":"Parses a CSR in DER (binary) format.\n\nReturns an `:ok` tuple in case of success, or an `:error` tuple in case of\nfailure. Possible error reasons are:\n\n  * `:malformed` - the data could not be decoded as a CSR","ref":"X509.CSR.html#from_der/1"},{"type":"function","title":"X509.CSR.from_der!/1","doc":"Attempts to parse a CSR in DER (binary) format. Raises in case of failure.","ref":"X509.CSR.html#from_der!/1"},{"type":"function","title":"X509.CSR.from_pem/1","doc":"Parses a CSR in PEM format.\n\nProcesses the first PEM entry of type CERTIFICATE REQUEST found in the input.\nReturns an `:ok` tuple in case of success, or an `:error` tuple in case of\nfailure. Possible error reasons are:\n\n  * `:not_found` - no PEM entry of type CERTIFICATE REQUEST was found\n  * `:malformed` - the entry could not be decoded as a CSR","ref":"X509.CSR.html#from_pem/1"},{"type":"function","title":"X509.CSR.from_pem!/1","doc":"Attempts to parse a CSR in PEM format. Raises in case of failure.\n\nProcesses the first PEM entry of type CERTIFICATE REQUEST found in the input.","ref":"X509.CSR.html#from_pem!/1"},{"type":"function","title":"X509.CSR.new/3","doc":"Returns a `:CertificationRequest` record for the given key pair and subject.\n\nSupports RSA and EC private keys. The public key is extracted from the\nprivate key (unless overridden; see Options below) and encoded, together with\nthe subject, in the CSR. The CSR is then signed with the private key, using a\nconfigurable hash algorithm.\n\nThe private key may be specified as an 'engine reference'. Please refer to\ndocumentation for Erlang/OTP's `:crypto` application for further information\nabout engines.\n\nThe default hash algorithm is `:sha256`. An alternative algorithm can be\nspecified using the `:hash` option. Possible values include `:sha224`,\n`:sha256`, `:sha384`, `:sha512`.\n\nOlder hash algorithms, supported for compatibility with older software only,\ninclude `:md5` (RSA only) and `:sha`. The use of these algorithms is\ndiscouraged.","ref":"X509.CSR.html#new/3"},{"type":"function","title":"Options: - X509.CSR.new/3","doc":"* `:hash` - the hashing algorithm to use when signing the CSR (default:\n  `:sha256`)\n* `:extension_request` - a list of certificate extensions to be included as\n  an `extensionRequest` attribute (see `X509.Certificate.Extension`)\n* `:public_key` - the public key to include in the CSR; by default the public\n  key is derived from the private key, but if that does not work (for certain\n  private keys stored in an 'engine') it can be useful to override the value\n  using this option (default: from private key)","ref":"X509.CSR.html#new/3-options"},{"type":"function","title":"Example: - X509.CSR.new/3","doc":"```\n  iex> priv = X509.PrivateKey.new_ec(:secp256r1)\n  iex> csr = X509.CSR.new(priv, \"/C=US/ST=NT/L=Springfield/O=ACME Inc.\",\n  ...>   extension_request: [\n  ...>     X509.Certificate.Extension.subject_alt_name([\"www.example.net\"])\n  ...>   ]\n  ...> )\n  iex> X509.CSR.valid?(csr)\n  true\n  ```","ref":"X509.CSR.html#new/3-example"},{"type":"function","title":"X509.CSR.public_key/1","doc":"Extracts the public key from the CSR.","ref":"X509.CSR.html#public_key/1"},{"type":"function","title":"X509.CSR.subject/1","doc":"Returns the Subject field of the CSR.","ref":"X509.CSR.html#subject/1"},{"type":"opaque","title":"X509.CSR.t/0","doc":"`:CertificationRequest` record , as used in Erlang's `:public_key` module","ref":"X509.CSR.html#t:t/0"},{"type":"function","title":"X509.CSR.to_der/1","doc":"Converts a CSR to DER (binary) format.","ref":"X509.CSR.html#to_der/1"},{"type":"function","title":"X509.CSR.to_pem/1","doc":"Converts a CSR to PEM format.","ref":"X509.CSR.html#to_pem/1"},{"type":"function","title":"X509.CSR.valid?/1","doc":"Verifies whether a CSR has a valid signature.","ref":"X509.CSR.html#valid?/1"},{"type":"module","title":"X509.Certificate","doc":"Module for issuing and working with X.509 certificates.\n\nThe primary data type for this module is the `:OTPCertificate` record, but\nthe PEM and DER import and export functions also support the `:Certificate`\nrecord type. The former is more convenient to work with, since nested ASN.1\nelements are further decoded, and some named elements are identified by\natoms rather than OID values.","ref":"X509.Certificate.html"},{"type":"function","title":"X509.Certificate.extension/2","doc":"Looks up the value of a specific extension in a certificate.\n\nThe desired extension can be specified as an atom or an OID value. Returns\n`nil` if the specified extension is not present in the certificate.","ref":"X509.Certificate.html#extension/2"},{"type":"function","title":"X509.Certificate.extensions/1","doc":"Returns the list of extensions included in a certificate.","ref":"X509.Certificate.html#extensions/1"},{"type":"function","title":"X509.Certificate.from_der/2","doc":"Attempts to parse a certificate in DER (binary) format.\n\nThe optional second parameter specifies the record type to be returned:\n`:OTPCertificate` (default) or `:Certificate`.\n\nReturns an `:ok` tuple in case of success, or an `:error` tuple in case of\nfailure. Possible error reasons are:\n\n  * `:malformed` - the data could not be decoded as a certificate","ref":"X509.Certificate.html#from_der/2"},{"type":"function","title":"X509.Certificate.from_der!/2","doc":"Attempts to parse a certificate in DER (binary) format. Raises in case of failure.\n\nThe optional second parameter specifies the record type to be returned:\n`:OTPCertificate` (default) or `:Certificate`.","ref":"X509.Certificate.html#from_der!/2"},{"type":"function","title":"X509.Certificate.from_pem/2","doc":"Attempts to parse a certificate in PEM format.\n\nProcesses the first PEM entry of type CERTIFICATE found in the input. The\noptional second parameter specifies the record type to be returned:\n`:OTPCertificate` (default) or `:Certificate`.\n\nReturns an `:ok` tuple in case of success, or an `:error` tuple in case of\nfailure. Possible error reasons are:\n\n  * `:not_found` - no PEM entry of type CERTIFICATE was found\n  * `:malformed` - the entry could not be decoded as a certificate","ref":"X509.Certificate.html#from_pem/2"},{"type":"function","title":"X509.Certificate.from_pem!/2","doc":"Attempts to parse a certificate in PEM format. Raises in case of failure.\n\nProcesses the first PEM entry of type CERTIFICATE found in the input. The\noptional second parameter specifies the record type to be returned:\n`:OTPCertificate` (default) or `:Certificate`.","ref":"X509.Certificate.html#from_pem!/2"},{"type":"function","title":"X509.Certificate.issuer/1","doc":"Returns the Issuer field of a certificate.","ref":"X509.Certificate.html#issuer/1"},{"type":"function","title":"X509.Certificate.issuer/2","doc":"Returns attribute values of the Issuer field of a certificate.\n\nSee also `X509.RDNSequence.get_attr/2`.","ref":"X509.Certificate.html#issuer/2"},{"type":"function","title":"X509.Certificate.new/5","doc":"Issues a new certificate.\n\nThe public key can be an RSA key or an EC key (which results in an ECDSA\ncertificate).\n\nThe Subject can be specified as a string, to be parsed by\n`X509.RDNSequence.new/1`, or a custom RDN sequence tuple.\n\nThe next parameters are the issuing certificate and the associated private\nkey (RSA or EC). The Issuer field of the new certificate is taken from the\nissuing certificate's Subject.","ref":"X509.Certificate.html#new/5"},{"type":"function","title":"Options: - X509.Certificate.new/5","doc":"* `:template` - an `X509.Certificate.Template` struct, or an atom selecting\n  a built-in template (default: `:server`)\n* `:hash` - the hashing algorithm to use when signing the certificate\n  (default: from template)\n* `:serial` - the certificate's serial number (an integer >0), `{:random, n}`\n  to generate an n-byte random value, or `nil`. (default: from template)\n* `:validity` - an integer specifying the certificate's validity in days,\n  or an `X509.Certificate.Validity` record defining the 'not before' and\n  'not after' timestamps (default: from template)\n* `:extensions` - a keyword list of extension names and values, to be merged\n  with the extensions defined in the template; refer to the\n  `X509.Certificate.Template` documentation for details","ref":"X509.Certificate.html#new/5-options"},{"type":"function","title":"X509.Certificate.public_key/1","doc":"Returns the public key embedded in a certificate.","ref":"X509.Certificate.html#public_key/1"},{"type":"function","title":"X509.Certificate.self_signed/3","doc":"Generates a new self-signed certificate.\n\nThe private key is used both to sign and to extract the public key to be\nembedded in the certificate. It can be an RSA key or an EC key (which results\nin an ECDSA certificate).\n\nThe Subject can be specified as a string, to be parsed by\n`X509.RDNSequence.new/1`, or a custom RDN sequence tuple. The same value is\nused in the Issuer field as well.","ref":"X509.Certificate.html#self_signed/3"},{"type":"function","title":"Options: - X509.Certificate.self_signed/3","doc":"* `:template` - an `X509.Certificate.Template` struct, or an atom selecting\n  a built-in template (default: `:server`)\n* `:hash` - the hashing algorithm to use when signing the certificate\n  (default: from template)\n* `:serial` - the certificate's serial number (default: from template, where\n  it will typically be set to `nil`, resulting in a random value)\n* `:validity` - an integer specifying the certificate's validity in days,\n  or an `X509.Certificate.Validity` record defining the 'not before' and\n  'not after' timestamps (default: from template)\n* `:extensions` - a keyword list of extension names and values, to be merged\n  with the extensions defined in the template; refer to the\n  `X509.Certificate.Template` documentation for details","ref":"X509.Certificate.html#self_signed/3-options"},{"type":"function","title":"X509.Certificate.serial/1","doc":"Returns the serial number of the certificate.","ref":"X509.Certificate.html#serial/1"},{"type":"function","title":"X509.Certificate.subject/1","doc":"Returns the Subject field of a certificate.","ref":"X509.Certificate.html#subject/1"},{"type":"function","title":"X509.Certificate.subject/2","doc":"Returns attribute values of the Subject field of a certificate.\n\nSee also `X509.RDNSequence.get_attr/2`.","ref":"X509.Certificate.html#subject/2"},{"type":"type","title":"X509.Certificate.t/0","doc":"`:OTPCertificate` record , as used in Erlang's `:public_key` module","ref":"X509.Certificate.html#t:t/0"},{"type":"function","title":"X509.Certificate.to_der/1","doc":"Converts a certificate to DER (binary) format.","ref":"X509.Certificate.html#to_der/1"},{"type":"function","title":"X509.Certificate.to_pem/1","doc":"Converts a certificate to PEM format.","ref":"X509.Certificate.html#to_pem/1"},{"type":"function","title":"X509.Certificate.validity/1","doc":"Returns the Validity of a certificate.","ref":"X509.Certificate.html#validity/1"},{"type":"function","title":"X509.Certificate.version/1","doc":"Returns the Version field of a certificate.\n\nReturns the X.509 certificate version as an atom, e.g. `:v3`.","ref":"X509.Certificate.html#version/1"},{"type":"module","title":"X509.Certificate.Extension","doc":"Convenience functions for creating `:Extension` records for use in\ncertificates.","ref":"X509.Certificate.Extension.html"},{"type":"type","title":"X509.Certificate.Extension.aia_access_method/0","doc":"","ref":"X509.Certificate.Extension.html#t:aia_access_method/0"},{"type":"function","title":"X509.Certificate.Extension.authority_info_access/1","doc":"The authority information access extension indicates how to access\ninformation and services for the issuer of the certificate in which the\nextension appears.\n\nInformation and services may include on-line validation services and CA\npolicy data. This extension may be included in end entity or CA certificates.\n\nThis extension is marked as non-critical.\n\nExample:\n\n    iex> X509.Certificate.Extension.authority_info_access(\n    ...>   ocsp: \"http://ocsp.example.net/\"\n    ...> )\n    {:Extension, {1, 3, 6, 1, 5, 5, 7, 1, 1}, false,\n     [\n       {:AccessDescription, {1, 3, 6, 1, 5, 5, 7, 48, 1},\n        {:uniformResourceIdentifier, \"http://ocsp.example.net/\"}}\n     ]}","ref":"X509.Certificate.Extension.html#authority_info_access/1"},{"type":"function","title":"X509.Certificate.Extension.authority_key_identifier/1","doc":"The authority key identifier extension provides a means of identifying the\npublic key corresponding to the private key used to sign a certificate.\n\nThe value should be a public key record. It is possible to pass a\npre-calculated SHA-1 value, though it is preferred to let the function\ncalculate the correct value over the original public key.\n\nThis extension is marked as non-critical.\n\nExample:\n\n    iex> X509.Certificate.Extension.authority_key_identifier({:RSAPublicKey, 55, 3})\n    {:Extension, {2, 5, 29, 35}, false,\n     {:AuthorityKeyIdentifier,\n      <<187, 230, 143, 92, 27, 37, 166, 93, 176, 137, 154, 111, 62, 152,\n       215, 114, 3, 214, 71, 170>>, :asn1_NOVALUE, :asn1_NOVALUE}}","ref":"X509.Certificate.Extension.html#authority_key_identifier/1"},{"type":"function","title":"X509.Certificate.Extension.basic_constraints/2","doc":"The basic constraints extension identifies whether the subject of the\ncertificate is a CA and the maximum depth of valid certification\npaths that include this certificate.\n\nThis extension is always marked as critical for CA certificates, and\nnon-critical when CA is set to false.\n\nExamples:\n\n    iex> X509.Certificate.Extension.basic_constraints(false)\n    {:Extension, {2, 5, 29, 19}, false,\n     {:BasicConstraints, false, :asn1_NOVALUE}}\n\n    iex> X509.Certificate.Extension.basic_constraints(true)\n    {:Extension, {2, 5, 29, 19}, true, {:BasicConstraints, true, :asn1_NOVALUE}}\n\n    iex> X509.Certificate.Extension.basic_constraints(true, 0)\n    {:Extension, {2, 5, 29, 19}, true, {:BasicConstraints, true, 0}}","ref":"X509.Certificate.Extension.html#basic_constraints/2"},{"type":"function","title":"X509.Certificate.Extension.crl_distribution_points/1","doc":"The CRL distribution points extension identifies how CRL information\nis obtained.\n\nThe list of distribution points must be specified as a list of strings\ncontaining HTTP, FTP and/or LDAP URIs. Other types of distribution points are\ndefined in RFC 5280, but are not supported by this function at this time.\n\nThis extension is marked as non-critical.\n\nExample:\n\n    iex> X509.Certificate.Extension.crl_distribution_points([\"http://crl.example.org/root.crl\"])\n    {:Extension, {2, 5, 29, 31}, false,\n     [\n       {:DistributionPoint,\n        {:fullName, [uniformResourceIdentifier: ~c\"http://crl.example.org/root.crl\"]},\n        :asn1_NOVALUE, :asn1_NOVALUE}\n     ]}","ref":"X509.Certificate.Extension.html#crl_distribution_points/1"},{"type":"function","title":"X509.Certificate.Extension.ext_key_usage/1","doc":"This extension indicates one or more purposes for which the certified\npublic key may be used, in addition to or in place of the basic\npurposes indicated in the key usage extension.  In general, this\nextension will appear only in end entity certificates.\n\nEach of the values in the list must be an OID, either in raw tuple format or\nas an atom representing a well-known OID. Typical examples include:\n\n* `:serverAuth` - TLS WWW server authentication\n* `:clientAuth` - TLS WWW client authentication\n* `:codeSigning` - Signing of downloadable executable code\n* `:emailProtection` - Email protection\n* `:timeStamping` - Binding the hash of an object to a time\n* `:ocspSigning` - Signing OCSP responses\n\nThis extension is marked as non-critical.\n\nExample:\n\n    iex> X509.Certificate.Extension.ext_key_usage([:serverAuth, :clientAuth])\n    {:Extension, {2, 5, 29, 37}, false,\n     [{1, 3, 6, 1, 5, 5, 7, 3, 1}, {1, 3, 6, 1, 5, 5, 7, 3, 2}]}","ref":"X509.Certificate.Extension.html#ext_key_usage/1"},{"type":"type","title":"X509.Certificate.Extension.extension_id/0","doc":"","ref":"X509.Certificate.Extension.html#t:extension_id/0"},{"type":"function","title":"X509.Certificate.Extension.find/2","doc":"Looks up the value of a specific extension in a list.\n\nThe desired extension can be specified as an atom or an OID value. Returns\n`nil` if the specified extension is not present in the certificate.","ref":"X509.Certificate.Extension.html#find/2"},{"type":"function","title":"X509.Certificate.Extension.key_usage/1","doc":"The key usage extension defines the purpose (e.g., encipherment,\nsignature, certificate signing) of the key contained in the\ncertificate.\n\nEach of the key usage values must be one of the atoms recognized by Erlang's\n`:public_key` module, though this is not verified by this function.\n\nThis extension is always marked as critical.\n\nExample:\n\n    iex> X509.Certificate.Extension.key_usage([:digitalSignature, :keyEncipherment])\n    {:Extension, {2, 5, 29, 15}, true, [:digitalSignature, :keyEncipherment]}","ref":"X509.Certificate.Extension.html#key_usage/1"},{"type":"type","title":"X509.Certificate.Extension.key_usage_value/0","doc":"Supported values in the key usage extension","ref":"X509.Certificate.Extension.html#t:key_usage_value/0"},{"type":"function","title":"X509.Certificate.Extension.ocsp_nocheck/0","doc":"The OCSP Nocheck extension indicates that the OCSP client can trust this\nOCSP responder certificate for the lifetime of the certificate, and no\nrevocation checks are needed.\n\nThis extension has no value, it acts as a flag simply by being present in a\ncertificate's extension list.\n\nThis extension is marked as non-critical.\n\nExample:\n\n    iex> X509.Certificate.Extension.ocsp_nocheck()\n    {:Extension, {1, 3, 6, 1, 5, 5, 7, 48, 1, 5}, false, <<5, 0>>}","ref":"X509.Certificate.Extension.html#ocsp_nocheck/0"},{"type":"type","title":"X509.Certificate.Extension.san_value/0","doc":"An entry for use in the subject alternate name extension. Strings are mapped\nto DNSName values, tuples must contain values supported by Erlang's\n`:public_key` module","ref":"X509.Certificate.Extension.html#t:san_value/0"},{"type":"function","title":"X509.Certificate.Extension.subject_alt_name/1","doc":"The subject alternative name extension allows identities to be bound\nto the subject of the certificate.  These identities may be included\nin addition to or in place of the identity in the subject field of\nthe certificate.  Defined options include an Internet electronic mail\naddress, a DNS name, an IP address, and a Uniform Resource Identifier\n(URI).\n\nTypically the subject alternative name extension is used to define the\nDNS domains or hostnames for which a certificate is valid, so this\nfunction maps string values to DNSName entries. Values of other types\ncan be passed in a type/value tuples as supported by Erlang's `:public_key`\nmodule, if required. Note that Erlang will typically require the value\nto be a character list.\n\nThis extension is marked as non-critical.\n\nExample:\n\n    iex> X509.Certificate.Extension.subject_alt_name([\"www.example.com\", \"example.com\"])\n    {:Extension, {2, 5, 29, 17}, false,\n     [dNSName: ~c\"www.example.com\", dNSName: ~c\"example.com\"]}\n\n    iex> X509.Certificate.Extension.subject_alt_name(emailAddress: ~c\"user@example.com\")\n    {:Extension, {2, 5, 29, 17}, false,\n     [emailAddress: ~c\"user@example.com\"]}","ref":"X509.Certificate.Extension.html#subject_alt_name/1"},{"type":"function","title":"X509.Certificate.Extension.subject_key_identifier/1","doc":"The subject key identifier extension provides a means of identifying\ncertificates that contain a particular public key.\n\nThe value should be a public key record or a pre-calculated binary SHA-1\nvalue.\n\nThis extension is marked as non-critical.\n\nExample:\n\n    iex> X509.Certificate.Extension.subject_key_identifier({:RSAPublicKey, 55, 3})\n    {:Extension, {2, 5, 29, 14}, false,\n     <<187, 230, 143, 92, 27, 37, 166, 93, 176, 137, 154, 111, 62, 152,\n      215, 114, 3, 214, 71, 170>>}","ref":"X509.Certificate.Extension.html#subject_key_identifier/1"},{"type":"type","title":"X509.Certificate.Extension.t/0","doc":"`:Extension` record, as used in Erlang's `:public_key` module","ref":"X509.Certificate.Extension.html#t:t/0"},{"type":"module","title":"X509.Certificate.Template","doc":"Certificate templates.","ref":"X509.Certificate.Template.html"},{"type":"type","title":"X509.Certificate.Template.named_template/0","doc":"","ref":"X509.Certificate.Template.html#t:named_template/0"},{"type":"function","title":"X509.Certificate.Template.new/2","doc":"Returns a template, optionally customized with user-provided validity, hash\nand extensions options.\n\nThe base template can be selected from a list of built-in named templates,\nor as a custom template. The following named templates are supported:\n\n  * `:root_ca` - intended for a self-signed root CA.\n\n    The default path length constraint is set to 1, meaning the root CA can\n    be used to issue intermediate CAs, and those CAs can only sign end\n    certificates. The value can be overridden by passing a custom value\n    for the `:basic_constraints` extension.\n\n    The default validity is 25 years.\n\n  * `:ca` - intended for intermediate CA certificates.\n\n    The default path length constraint is set to 0, meaning the CA can only\n    sign end certificates. The value can be overridden by passing a custom\n    value for the `:basic_constraints` extension (assuming the issuing CA\n    allows it).\n\n    The Extended Key Usage extension is set to TLS server & client. Many\n    (but not all) TLS implementations will interpret this as a constraint\n    on the type of certificates the CA is allowed to issue. This constraint\n    can be removed by setting `:ext_key_usage` to `false`, or by overriding\n    the value to set the desired constraints.\n\n    The default validity is 10 years.\n\n  * `:server` - intended for end-certificates.\n\n    The Extended Key Usage extension is set to TLS server & client. For other\n    types of end-certificates, set the `:ext_key_usage` extension to the\n    desired value. It may be necessary to update the `:key_usage` value as\n    well.\n\n    The default validity is 1 year, plus a 30 day grace period.\n\n  * `:ocsp_responder` - designated responder to sign OCSP responses on behalf\n    of the issuing CA.\n\n    The Extended Key Usage extension is set to allow OCSP signing only. Must\n    be issued directly from the CA certificate for which OCSP responses will\n    be signed.\n\n    The OCSP Nocheck extension is included, to disable revocation checks for\n    the OCSP responder certificate. To exclude this extension override it\n    with a value of `false` (e.g. `extensions: [ocsp_nocheck: false]`)\n\n    The default validity is just 30 days, due to the fact that revocation\n    is not possible when OCSP Nocheck is set.\n\nAll of the above templates generate a random 8 byte (64 bit) serial number,\nwhich can be overridden through the `:serial` option (see below).\n\nThe `extensions` attribute of a template is a keyword list of extension\nname/value pairs, where the value should typically be an\n`X509.Certificate.Extension` record. The `subject_key_identifier` and\n`authority_key_identifier` extensions may simply be set to `true`: the\nactual values will be calculated during the certificate signing process.","ref":"X509.Certificate.Template.html#new/2"},{"type":"function","title":"Options: - X509.Certificate.Template.new/2","doc":"* `:hash` - the hash algorithm to use when signing the certificate\n  * `:serial` - the serial number of the certificate (an integer >0) or\n    `{:random, n}` to generate an n-byte random serial number\n  * `:validity` - override the validity period; can be specified as the\n    number of days (integer) or a `X509.Certificate.Validity` value\n  * `:extensions` - a keyword list of extensions to be merged into the\n    template's defaults; set an extension value to `false` to exclude that\n    extension from the certificate","ref":"X509.Certificate.Template.html#new/2-options"},{"type":"function","title":"Examples: - X509.Certificate.Template.new/2","doc":"iex> X509.Certificate.Template.new(:root_ca,\n    ...>   hash: :sha512, serial: 1,\n    ...>   extensions: [authority_key_identifier: false]\n    ...> )\n    %X509.Certificate.Template{\n      extensions: [\n        basic_constraints: {:Extension, {2, 5, 29, 19}, true,\n         {:BasicConstraints, true, 1}},\n        key_usage: {:Extension, {2, 5, 29, 15}, true,\n         [:digitalSignature, :keyCertSign, :cRLSign]},\n        subject_key_identifier: true,\n        authority_key_identifier: false\n      ],\n      hash: :sha512,\n      serial: 1,\n      validity: 9131\n    }\n\n    iex> X509.Certificate.Template.new(:server, extensions: [\n    ...>   ext_key_usage: X509.Certificate.Extension.ext_key_usage([:codeSigning])\n    ...> ])\n    %X509.Certificate.Template{\n      extensions: [\n        basic_constraints: {:Extension, {2, 5, 29, 19}, false,\n         {:BasicConstraints, false, :asn1_NOVALUE}},\n        key_usage: {:Extension, {2, 5, 29, 15}, true,\n         [:digitalSignature, :keyEncipherment]},\n        subject_key_identifier: true,\n        authority_key_identifier: true,\n        ext_key_usage: {:Extension, {2, 5, 29, 37}, false,\n         [{1, 3, 6, 1, 5, 5, 7, 3, 3}]}\n      ],\n      hash: :sha256,\n      serial: {:random, 8},\n      validity: 395\n    }","ref":"X509.Certificate.Template.html#new/2-examples"},{"type":"type","title":"X509.Certificate.Template.t/0","doc":"","ref":"X509.Certificate.Template.html#t:t/0"},{"type":"module","title":"X509.Certificate.Validity","doc":"Convenience functions for creating `:Validity` records for use in\ncertificates. The `:Validity` record represents the X.509 Validity\ntype, defining the validity of a certificate in terms of `notBefore`\nand `notAfter` timestamps.","ref":"X509.Certificate.Validity.html"},{"type":"function","title":"X509.Certificate.Validity.days_from_now/2","doc":"Creates a new `:Validity` record with an `notAfter` value a given number of\ndays in the future. The `notBefore` value can be backdated (by default\n300 seconds) to avoid newly issued certificates\nfrom being rejected by peers due to poorly synchronized clocks.\n\nFor CA certificates, consider using `new/2` instead, with a `not_before`\nvalue that does not reveal the exact time when the key pair was generated.\nThis minimizes information leakage about the state of the RNG.","ref":"X509.Certificate.Validity.html#days_from_now/2"},{"type":"function","title":"X509.Certificate.Validity.new/2","doc":"Creates a new `:Validity` record with the given start and end timestamps\nin DateTime format.","ref":"X509.Certificate.Validity.html#new/2"},{"type":"function","title":"Examples: - X509.Certificate.Validity.new/2","doc":"iex> {:ok, not_before, 0} = DateTime.from_iso8601(\"2018-01-01T00:00:00Z\")\n    iex> {:ok, not_after, 0} = DateTime.from_iso8601(\"2018-12-31T23:59:59Z\")\n    iex> X509.Certificate.Validity.new(not_before, not_after)\n    {:Validity, {:utcTime, ~c\"180101000000Z\"}, {:utcTime, ~c\"181231235959Z\"}}\n\n    iex> {:ok, not_before, 0} = DateTime.from_iso8601(\"2051-01-01T00:00:00Z\")\n    iex> {:ok, not_after, 0} = DateTime.from_iso8601(\"2051-12-31T23:59:59Z\")\n    iex> X509.Certificate.Validity.new(not_before, not_after)\n    {:Validity, {:generalTime, ~c\"20510101000000Z\"},\n      {:generalTime, ~c\"20511231235959Z\"}}","ref":"X509.Certificate.Validity.html#new/2-examples"},{"type":"type","title":"X509.Certificate.Validity.t/0","doc":"`:Validity` record, as used in Erlang's `:public_key` module","ref":"X509.Certificate.Validity.html#t:t/0"},{"type":"type","title":"X509.Certificate.Validity.time/0","doc":"X.509 Time type (UTCTime or GeneralizedTime)","ref":"X509.Certificate.Validity.html#t:time/0"},{"type":"module","title":"X509.PrivateKey","doc":"Functions for generating, reading and writing RSA and EC private keys.","ref":"X509.PrivateKey.html"},{"type":"module","title":"Example use with :public_key - X509.PrivateKey","doc":"Encryption and decryption:\n\n    iex> private_key = X509.PrivateKey.new_rsa(2048)\n    iex> public_key = X509.PublicKey.derive(private_key)\n    iex> plaintext = \"Hello, world!\"\n    iex> ciphertext = :public_key.encrypt_public(plaintext, public_key)\n    iex> :public_key.decrypt_private(ciphertext, private_key)\n    \"Hello, world!\"\n\nSigning and signature verification:\n\n    iex> private_key = X509.PrivateKey.new_ec(:secp256r1)\n    iex> public_key = X509.PublicKey.derive(private_key)\n    iex> message = \"Hello, world!\"\n    iex> signature = :public_key.sign(message, :sha256, private_key)\n    iex> :public_key.verify(message, :sha256, signature, public_key)\n    true\n\nNote that in practice it is not a good idea to directly encrypt a message\nwith asymmetrical cryptography. The examples above are deliberate\nover-simpliciations intended to highlight the `:public_key` API calls.","ref":"X509.PrivateKey.html#module-example-use-with-public_key"},{"type":"function","title":"X509.PrivateKey.from_der/1","doc":"Attempts to parse a private key in DER (binary) format.\n\nUnwraps the PKCS#8 PrivateKeyInfo container, if present.\n\nReturns an `:ok` tuple in case of success, or an `:error` tuple in case of\nfailure. Possible error reasons are:\n\n  * `:malformed` - the data could not be decoded as a private key","ref":"X509.PrivateKey.html#from_der/1"},{"type":"function","title":"X509.PrivateKey.from_der!/1","doc":"Attempts to parse a private key in DER (binary) format. Raises in case of failure.\n\nUnwraps the PKCS#8 PrivateKeyInfo container, if present.","ref":"X509.PrivateKey.html#from_der!/1"},{"type":"function","title":"X509.PrivateKey.from_pem/2","doc":"Attempts to parse a private key in PEM format.\n\nProcesses the first PEM entry of type PRIVATE KEY, RSA PRIVATE KEY or EC\nPRIVATE KEY found in the input. Unwraps the PKCS#8 PrivateKeyInfo container,\nif present. Returns an `:ok` tuple in case of success, or an `:error` tuple\nin case of failure. Possible error reasons are:\n\n  * `:not_found` - no PEM entry of a supported PRIVATE KEY type was found\n  * `:malformed` - the entry could not be decoded as a private key","ref":"X509.PrivateKey.html#from_pem/2"},{"type":"function","title":"Options: - X509.PrivateKey.from_pem/2","doc":"* `:password` - the password used to decrypt an encrypted private key; may\n    be specified as a string or a charlist","ref":"X509.PrivateKey.html#from_pem/2-options"},{"type":"function","title":"X509.PrivateKey.from_pem!/2","doc":"Attempts to parse a private key in PEM format. Raises in case of failure.\n\nProcesses the first PEM entry of type PRIVATE KEY, RSA PRIVATE KEY or EC\nPRIVATE KEY found in the input. Unwraps the PKCS#8 PrivateKeyInfo container,\nif present.","ref":"X509.PrivateKey.html#from_pem!/2"},{"type":"function","title":"Options: - X509.PrivateKey.from_pem!/2","doc":"* `:password` - the password used to decrypt an encrypted private key; may\n    be specified as a string or a charlist","ref":"X509.PrivateKey.html#from_pem!/2-options"},{"type":"function","title":"X509.PrivateKey.new_ec/1","doc":"Generates a new EC private key. To derive the public key, use\n`X509.PublicKey.derive/1`.\n\nThe first parameter must specify a named curve. The curve can be specified\nas an atom or an OID tuple.\n\nNote that this function uses Erlang/OTP's `:public_key` application, which\ndoes not support all curve names returned by the `:crypto.ec_curves/0`\nfunction. In particular, the NIST Prime curves must be selected by their\nSECG id, e.g. NIST P-256 is `:secp256r1` rather than `:prime256v1`. Please\nrefer to [RFC4492 appendix A](https://www.rfc-editor.org/rfc/rfc4492.html#appendix-A)\nfor a mapping table.","ref":"X509.PrivateKey.html#new_ec/1"},{"type":"function","title":"X509.PrivateKey.new_rsa/2","doc":"Generates a new RSA private key. To derive the public key, use\n`X509.PublicKey.derive/1`.\n\nThe key length in bits must be specified as an integer (minimum 256 bits).\nThe default exponent of 65537 can be overridden using the `:exponent`\noption. Warning: the custom exponent value is not checked for safety!","ref":"X509.PrivateKey.html#new_rsa/2"},{"type":"type","title":"X509.PrivateKey.t/0","doc":"RSA or EC private key","ref":"X509.PrivateKey.html#t:t/0"},{"type":"function","title":"X509.PrivateKey.to_der/2","doc":"Converts a private key to DER (binary) format.","ref":"X509.PrivateKey.html#to_der/2"},{"type":"function","title":"Options: - X509.PrivateKey.to_der/2","doc":"* `:wrap` - Wrap the private key in a PKCS#8 PrivateKeyInfo container\n    (default: `false`, but always `true` for EdDSA keys)","ref":"X509.PrivateKey.html#to_der/2-options"},{"type":"function","title":"X509.PrivateKey.to_pem/2","doc":"Converts a private key to PEM format.","ref":"X509.PrivateKey.html#to_pem/2"},{"type":"function","title":"Options: - X509.PrivateKey.to_pem/2","doc":"* `:wrap` - Wrap the private key in a PKCS#8 PrivateKeyInfo container\n    (default: `false`, but always `true` for EdDSA keys)\n  * `:password` - If a password is specified, the private key is encrypted\n    using 3DES; the password will be required to decode the PEM entry","ref":"X509.PrivateKey.html#to_pem/2-options"},{"type":"function","title":"X509.PrivateKey.unwrap/1","doc":"Extracts a private key from a PKCS#8 PrivateKeyInfo container.","ref":"X509.PrivateKey.html#unwrap/1"},{"type":"function","title":"X509.PrivateKey.wrap/1","doc":"Wraps a private key in a PKCS#8 PrivateKeyInfo container.","ref":"X509.PrivateKey.html#wrap/1"},{"type":"module","title":"X509.PublicKey","doc":"Functions for deriving, reading and writing RSA and EC public keys.","ref":"X509.PublicKey.html"},{"type":"function","title":"X509.PublicKey.derive/1","doc":"Derives the public key from the given RSA or EC private key.\n\nThe private key may be specified as an 'engine reference'. Please refer to\ndocumentation for Erlang/OTP's `:crypto` application for further information\nabout engines. However, please note that `:crypto` may not support this API\nfor all key types.","ref":"X509.PublicKey.html#derive/1"},{"type":"function","title":"X509.PublicKey.from_der/1","doc":"Attempts to parse a public key in DER (binary) format.\n\nUnwraps a SubjectPublicKeyInfo style container, if present.\n\nReturns an `:ok` tuple in case of success, or an `:error` tuple in case of\nfailure. Possible error reasons are:\n\n  * `:malformed` - the data could not be decoded as a public key","ref":"X509.PublicKey.html#from_der/1"},{"type":"function","title":"X509.PublicKey.from_der!/1","doc":"Attempts to parse a public key in DER (binary) format. Raises in case of failure.\n\nUnwraps a SubjectPublicKeyInfo style container, if present.","ref":"X509.PublicKey.html#from_der!/1"},{"type":"function","title":"X509.PublicKey.from_pem/1","doc":"Attempts to parse a public key in PEM format.\n\nExpects the input string to include exactly one PEM entry, which must be of\ntype \"PUBLIC KEY\" or \"RSA PUBLIC KEY\". Unwraps a SubjectPublicKeyInfo\nstyle container, if present. Returns an `:ok` tuple in case of success, or\nan `:error` tuple in case of failure. Possible error reasons are:\n\n  * `:not_found` - no PEM entry of a supported PRIVATE KEY type was found\n  * `:malformed` - the entry could not be decoded as a public key","ref":"X509.PublicKey.html#from_pem/1"},{"type":"function","title":"X509.PublicKey.from_pem!/1","doc":"Attempts to parse a public key in PEM format. Raises in case of failure.\n\nExpects the input string to include exactly one PEM entry, which must be of\ntype \"PUBLIC KEY\" or \"RSA PUBLIC KEY\". Unwraps a SubjectPublicKeyInfo style\ncontainer, if present.","ref":"X509.PublicKey.html#from_pem!/1"},{"type":"type","title":"X509.PublicKey.spki/0","doc":"SubjectPublicKeyInfo container","ref":"X509.PublicKey.html#t:spki/0"},{"type":"type","title":"X509.PublicKey.t/0","doc":"RSA or EC public key","ref":"X509.PublicKey.html#t:t/0"},{"type":"function","title":"X509.PublicKey.to_der/2","doc":"Converts a public key to DER (binary) format.","ref":"X509.PublicKey.html#to_der/2"},{"type":"function","title":"Options: - X509.PublicKey.to_der/2","doc":"* `:wrap` - Wrap the private key in a SubjectPublicKeyInfo container\n    (default: `true`)","ref":"X509.PublicKey.html#to_der/2-options"},{"type":"function","title":"X509.PublicKey.to_pem/2","doc":"Converts a public key to PEM format.","ref":"X509.PublicKey.html#to_pem/2"},{"type":"function","title":"Options: - X509.PublicKey.to_pem/2","doc":"* `:wrap` - Wrap the private key in a SubjectPublicKeyInfo container; for\n    RSA public keys this defaults to `true`, but for EC public keys this\n    option is ignored and the key is always exported in SubjectPublicKeyInfo\n    format","ref":"X509.PublicKey.html#to_pem/2-options"},{"type":"function","title":"X509.PublicKey.unwrap/1","doc":"Extracts a public key from a SubjectPublicKeyInfo style container.\n\nSupports the same container structures as `wrap/2`.","ref":"X509.PublicKey.html#unwrap/1"},{"type":"function","title":"X509.PublicKey.wrap/2","doc":"Wraps a public key in a SubjectPublicKeyInfo (or similar) container.\n\nThe following container types are supported:\n\n  * `:SubjectPublicKeyInfo` - standard X.509 structure for storing public\n    keys (default)\n  * `:OTPSubjectPublicKeyInfo` - Erlang/OTP record variant of\n    `:SubjectPublicKeyInfo`, for use in the `:OTPCertificate` record\n  * `:CertificationRequestInfo_subjectPKInfo` - for use in a PKCS#10\n    CertificationRequest (CSR)","ref":"X509.PublicKey.html#wrap/2"},{"type":"module","title":"X509.RDNSequence","doc":"Convenience functions for creating `:rdnSequence` tuples, as defined in\nErlang's `:public_key` module as the `issuer_name()` type, and representing\nthe X.509 RDNSequence type. RDNSequences are primarily used for the Subject\nand Issuer fields of certificates, as well as the Subject field of CSRs.\n\nNote that this module implements a commonly used subset of RDNSequence\nvalues. It supports only a single attribute type/value pair for each element\nin the sequence, and it implements the attribute types specified in RFC5280,\nsection 4.1.2.4, with a few extensions from LDAP:\n\n* countryName (C)\n* organizationName (O)\n* organizationalUnitName (OU)\n* dnQualifier\n* stateOrProvinceName (ST)\n* commonName (CN)\n* serialNumber\n* localityName (L)\n* title\n* name\n* surname (SN)\n* givenName (GN)\n* initials\n* pseudonym\n* generationQualifier\n* domainComponent (DC)\n* emailAddress (E)\n\nThis module encodes values as UTF8String where possible, or else\nPrintableString/IA5String where required.","ref":"X509.RDNSequence.html"},{"type":"type","title":"X509.RDNSequence.attr/0","doc":"RDN type/value pair.\n\nThe first element must be a string (short or long form) or atom (long form)\nmatching one of the supported attribute types. The second element is the\nassociated string value, which will be encoded as appropriate for\nthe attribute type.\n\nAlternatively, the attribute_type can be specified as an OID, in which case\nthe value is passed to Erlang's `:public_key` module as-is. Examples of\nacceptable values include `'character list'` and `{:utf8String, \"string\"}`.","ref":"X509.RDNSequence.html#t:attr/0"},{"type":"type","title":"X509.RDNSequence.attr_list/0","doc":"List of RDN type/value pairs","ref":"X509.RDNSequence.html#t:attr_list/0"},{"type":"function","title":"X509.RDNSequence.get_attr/2","doc":"Extracts the values for the specified attributes from a `:rdnSequence` tuple.\n\nThe attribute type may be specified as an attribute name (long or short form,\nas a string, or long from as an atom) or an OID tuple. Refer to the\ndocumentation at the top of this module for a list of supported attributes.\n\nSince an attribute may appear more than once in an RDN sequence the result is\na list of values.","ref":"X509.RDNSequence.html#get_attr/2"},{"type":"function","title":"Examples: - X509.RDNSequence.get_attr/2","doc":"iex> X509.RDNSequence.new(\"/C=US/CN=Bob\") |> X509.RDNSequence.get_attr(:countryName)\n    [\"US\"]\n    iex> X509.RDNSequence.new(\"/C=US/CN=Bob\") |> X509.RDNSequence.get_attr(\"commonName\")\n    [\"Bob\"]\n    iex> X509.RDNSequence.new(\"C=CN, givenName=麗\") |> X509.RDNSequence.get_attr(\"GN\")\n    [\"麗\"]","ref":"X509.RDNSequence.html#get_attr/2-examples"},{"type":"function","title":"X509.RDNSequence.new/2","doc":"Creates a new `:rdnSequence` tuple.\n\nThe value can be specified in one of the following formats:\n\n  * A string specifying the attributes in hierarchical format, e.g.\n    \"/C=US/ST=NT/L=Springfield/O=ACME Inc.\"\n  * A string specifying a comma-separated list of attributes, e.g.\n    \"C=US, ST=NT, L=Springfield, O=ACME Inc.\"\n  * An RDN attribute list (see type documentation)\n\nNote that the string parsers for the first two formats do not (currently)\nrecognize escape characters: separator characters ('/' and ',', respectively)\nare not allowed in attribute values.\n\nThe optional second parameter can be used to select the output format:\n\n  * `:plain` - for use in `:Certificate` and `:CertificationRequest` records\n    (default)\n  * `:otp` - for use in `:OTPCertificate` records (see `X509.Certificate`)\n\nRaises an error when the given value cannot be parsed, contains unsupported\nattribute types, when attribute values exceed the maximum length\n('upper bound' in the RFC) or when values cannot be coerced into the\nexpected ASN.1 type.","ref":"X509.RDNSequence.html#new/2"},{"type":"type","title":"X509.RDNSequence.t/0","doc":"RDN sequence for use in OTP certificate and CSR records","ref":"X509.RDNSequence.html#t:t/0"},{"type":"function","title":"X509.RDNSequence.to_string/1","doc":"Converts an `:rdnSequence` tuple to a human readable string, in hierarchical\nformat.","ref":"X509.RDNSequence.html#to_string/1"},{"type":"function","title":"Examples: - X509.RDNSequence.to_string/1","doc":"iex> X509.RDNSequence.new(\"C=CN, givenName=麗\") |> X509.RDNSequence.to_string\n    \"/C=CN/GN=麗\"","ref":"X509.RDNSequence.html#to_string/1-examples"},{"type":"module","title":"X509.Test.CRLServer","doc":"Simple CRL responder for use in test suites.","ref":"X509.Test.CRLServer.html"},{"type":"function","title":"X509.Test.CRLServer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"X509.Test.CRLServer.html#child_spec/1"},{"type":"function","title":"X509.Test.CRLServer.get_port/1","doc":"Returns the TCP port number on which the specified X509.Test.Server instance\nis listening.","ref":"X509.Test.CRLServer.html#get_port/1"},{"type":"function","title":"X509.Test.CRLServer.put_crl/3","doc":"Adds or updates the CRL at the given path.","ref":"X509.Test.CRLServer.html#put_crl/3"},{"type":"function","title":"X509.Test.CRLServer.start_link/1","doc":"Starts a CRL responder.","ref":"X509.Test.CRLServer.html#start_link/1"},{"type":"function","title":"Options: - X509.Test.CRLServer.start_link/1","doc":"* `:port` - the TCP port to listen on; defaults to 0, meaning an ephemeral\n  port is selected by the operating system, which may be retrieved using\n  `get_port/1`","ref":"X509.Test.CRLServer.html#start_link/1-options"},{"type":"module","title":"X509.Test.Server","doc":"Simple TLS server for hosting `X509.Test.Suite` scenarios.","ref":"X509.Test.Server.html"},{"type":"function","title":"X509.Test.Server.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"X509.Test.Server.html#child_spec/1"},{"type":"function","title":"X509.Test.Server.get_port/1","doc":"Returns the TCP port number on which the specified X509.Test.Server instance\nis listening.","ref":"X509.Test.Server.html#get_port/1"},{"type":"function","title":"X509.Test.Server.log_opts/0","doc":"","ref":"X509.Test.Server.html#log_opts/0"},{"type":"function","title":"X509.Test.Server.start_link/1","doc":"Starts a test server for the given test suite.","ref":"X509.Test.Server.html#start_link/1"},{"type":"function","title":"Options: - X509.Test.Server.start_link/1","doc":"* `:port` - the TCP port to listen on; defaults to 0, meaning an ephemeral\n  port is selected by the operating system, which may be retrieved using\n  `get_port/1`\n* `:response` - the data to send back to clients when a successful connection\n  is established (default: \"OK\")","ref":"X509.Test.Server.html#start_link/1-options"},{"type":"module","title":"X509.Test.Suite","doc":"This module may be used to generate a suite of certificates for client or\nserver testing, and offers an `sni_fun` hook for setting up a test scenario\nbased on the requested hostname.","ref":"X509.Test.Suite.html"},{"type":"module","title":"Test scenarios: - X509.Test.Suite","doc":"* `valid` - presenting a valid server certificate\n\n* `valid-missing-chain` - presenting a valid server certificate, but\n  configured without the required intermediate CA; should be rejected unless\n  peer verification is disabled or the intermediate CA is trusted by the\n  client\n\n* `valid-expired-chain` - presenting a valid server certificate, but\n  configured with an expired intermediate CA; should be rejected unless\n  peer verification is disabled\n\n* `valid-revoked-chain` - presenting a valid server certificate, but\n  configured with a revoked intermediate CA; should be rejected unless\n  peer verification is disabled\n\n* `valid-wrong-key` - presenting a valid server certificate, but configured\n  with the wrong private key; should always be rejected\n\n* `valid-wrong-host` - presenting a valid server certificate with a SAN\n  hostname that does not match; should be rejected unless peer verification\n  is disabled\n\n* `valid-cross-signed` - presenting a valid server certificate, cross-signed\n  by an alternative root CA, and with a certificate chain that resolves to\n  both the standard root CA and the cross-signing root CA\n\n* `valid.wildcard` - presenting a valid wildcard server certificate\n\n* `wildcard` - presenting a valid wildcard server certificate, but without\n   a SAN hostname for the bare domain; should be rejected unless peer\n   verification is disabled\n\n* `invalid.subdomain.wildcard` - presenting a valid wildcard server\n   certificate, but accessed using an invalid nested subdomain; should be\n   rejected unless peer verification is disabled\n\n * `expired` - presenting an expired server certificate; should be rejected\n   unless peer verification is disabled\n\n * `revoked` - presenting a revoked server certificate; should be rejected\n   unless peer verification is disabled\n\n* `selfsigned` - presenting a self-signed server certificate; should normally\n  be rejected by a client unless server certificate verification is disabled\n  or the client is configured to explicitly allow the specific certificate\n  ('pinning')\n\n* `selfsigned-wrong-key` - presenting a self-signed server certificate, but\n  configured with the wrong private key; should always be rejected\n\n* `selfsigned-wrong-host` - presenting a self-signed server certificate with\n  a SAN hostname that does not match; should be rejected unless peer\n  verification is disabled\n\n* `client-cert` - requires that the client present a valid certificate","ref":"X509.Test.Suite.html#module-test-scenarios"},{"type":"function","title":"X509.Test.Suite.new/1","doc":"Builds and returns a new test suite.","ref":"X509.Test.Suite.html#new/1"},{"type":"function","title":"Options: - X509.Test.Suite.new/1","doc":"* `:domain` - the test domain to use; any subdomain for the given domain\n  needs to resolve to the IP address where the test server will be hosted,\n  e.g. 127.0.0.1 or ::1; the default value is 'localtest.me', which requires\n  Internet access during test execution\n* `:crl_server` - the base URL for a CRL server that may be used as a CRL DP;\n  if none is specified, no CRL DPs are included in the generated\n  certificates, and revocation scenarios are not supported\n* `:key_type` - the type of private keys to generate; may be set to `{:rsa,\n  bits}` to select RSA keys of the given length, or `{:ec, curve}` to select\n  ECC keys based on the given curve (default:\n  `{:rsa, 1024}`)","ref":"X509.Test.Suite.html#new/1-options"},{"type":"function","title":"X509.Test.Suite.sni_fun/1","doc":"Returns a suitable SNI (Server Name Indication) handler function for the\ngiven test suite. May be used to configure custom servers to act as a test\nsuite endpoint.\n\nIn addition to setting the `sni_fun` parameter to the return value of this\nfunction, the `reuse_sessions` parameter must be set to `false`. This\nensures that a new handshake is performed on each connection.","ref":"X509.Test.Suite.html#sni_fun/1"},{"type":"type","title":"X509.Test.Suite.t/0","doc":"","ref":"X509.Test.Suite.html#t:t/0"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.9.1 (2025-06-27) - Changelog","doc":"","ref":"changelog.html#v0-9-1-2025-06-27"},{"type":"extras","title":"Fixes - Changelog","doc":"* [X509.Certificate] Fix signature algorithm for certificates signed by EdDSA keys","ref":"changelog.html#fixes"},{"type":"extras","title":"v0.9.0 (2025-06-20) - Changelog","doc":"","ref":"changelog.html#v0-9-0-2025-06-20"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support OTP 28: requires 28.0.1 or later; see caveats in README.md\n* Add support for EdDSA keys","ref":"changelog.html#enhancements"},{"type":"extras","title":"v0.8.10 (2024-10-16) - Changelog","doc":"","ref":"changelog.html#v0-8-10-2024-10-16"},{"type":"extras","title":"Fixes - Changelog","doc":"* Fix version check for Elixir by [@wojtekmach](https://github.com/wojtekmach)\n* Ensure application is started before running task by [@josevalim](https://github.com/josevalim)\n* Remove unnecessary file accidentally included in Hex package of v0.8.9 (as reported in [#79](https://github.com/voltone/x509/issues/79))","ref":"changelog.html#fixes-1"},{"type":"extras","title":"v0.8.9 (2024-06-24) - Changelog","doc":"","ref":"changelog.html#v0-8-9-2024-06-24"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support OTP 27\n* Clean up deprecation warnings","ref":"changelog.html#enhancements-1"},{"type":"extras","title":"v0.8.8 (2023-08-30) - Changelog","doc":"","ref":"changelog.html#v0-8-8-2023-08-30"},{"type":"extras","title":"Fixes - Changelog","doc":"* Avoid Logger.warn deprecation warning on recent Elixir versions","ref":"changelog.html#fixes-2"},{"type":"extras","title":"v0.8.7 (2023-05-31) - Changelog","doc":"","ref":"changelog.html#v0-8-7-2023-05-31"},{"type":"extras","title":"Fixes - Changelog","doc":"* Compatibility with Elixir 1.15","ref":"changelog.html#fixes-3"},{"type":"extras","title":"v0.8.6 (2023-04-04) - Changelog","doc":"","ref":"changelog.html#v0-8-6-2023-04-04"},{"type":"extras","title":"Fixes - Changelog","doc":"* Compatibility with Erlang/OTP 25.3","ref":"changelog.html#fixes-4"},{"type":"extras","title":"v0.8.5 (2022-05-25) - Changelog","doc":"","ref":"changelog.html#v0-8-5-2022-05-25"},{"type":"extras","title":"Fixes - Changelog","doc":"* [X509.Test.Server] Use `:ssl.handshake/3` if available","ref":"changelog.html#fixes-5"},{"type":"extras","title":"v0.8.4 (2022-03-01) - Changelog","doc":"","ref":"changelog.html#v0-8-4-2022-03-01"},{"type":"extras","title":"Fixes - Changelog","doc":"* [X509.RDNSequence] Fix handling of surname attribute","ref":"changelog.html#fixes-6"},{"type":"extras","title":"v0.8.3 (2021-06-07) - Changelog","doc":"","ref":"changelog.html#v0-8-3-2021-06-07"},{"type":"extras","title":"Enhancements - Changelog","doc":"* [X509.PublicKey] Support 'engine' reference for private keys in `derive/1`\n* [X509.CSR] Support 'engine' reference for private keys in `new/2,3`\n* [X509.CSR] Add `:public_key` option for `new/3`","ref":"changelog.html#enhancements-2"},{"type":"extras","title":"v0.8.2 (2020-11-05) - Changelog","doc":"","ref":"changelog.html#v0-8-2-2020-11-05"},{"type":"extras","title":"Fixes - Changelog","doc":"* Support for Elixir v1.11","ref":"changelog.html#fixes-7"},{"type":"extras","title":"v0.8.1 (2020-02-29) - Changelog","doc":"","ref":"changelog.html#v0-8-1-2020-02-29"},{"type":"extras","title":"Fixes - Changelog","doc":"* [X509.Certificate] Support both 'plain' and 'otp' `rdnSequence` records\n* [X509.CSR] Support both 'plain' and 'otp' `rdnSequence` records","ref":"changelog.html#fixes-8"},{"type":"extras","title":"v0.8.0 (2019-12-09) - Changelog","doc":"","ref":"changelog.html#v0-8-0-2019-12-09"},{"type":"extras","title":"Enhancements - Changelog","doc":"* [X509.CSR] Add support for extension requests","ref":"changelog.html#enhancements-3"},{"type":"extras","title":"v0.7.0 (2019-07-15) - Changelog","doc":"","ref":"changelog.html#v0-7-0-2019-07-15"},{"type":"extras","title":"Enhancements - Changelog","doc":"* [X509.Certificate.Template] Add OCSP responder template\n* [X509.Certificate.Extension] Add support for Authority Information Access\n  and OCSP Nocheck extensions","ref":"changelog.html#enhancements-4"},{"type":"extras","title":"Fixes - Changelog","doc":"* [X509.RDNSequence] Handle `teletexString` encoding (7-bit only, for now)\n* [X509.PrivateKey] Documentation fixes","ref":"changelog.html#fixes-9"},{"type":"extras","title":"v0.6.0 (2019-06-18) - Changelog","doc":"","ref":"changelog.html#v0-6-0-2019-06-18"},{"type":"extras","title":"Enhancements - Changelog","doc":"* [X509.PrivateKey] Allow encryption of PEM output\n* [X509.Test.Suite] Include 'localhost' in all certifictes\n* [X509.Test.Suite] Generate client certificate and associated key\n* [X509.Test.Server] Add 'client-cert' endpoint for testing with client\n  certificate\n* [`x509.gen.suite` Mix task] Add --force option\n* [`x509.gen.suite` Mix task] Add --password option\n* [`x509.gen.suite` Mix task] Generate 'ca_and_chain.pem' file\n* [`x509.gen.selfsigned` Mix task] Add --force option","ref":"changelog.html#enhancements-5"},{"type":"extras","title":"v0.5.4 (2019-04-15) - Changelog","doc":"","ref":"changelog.html#v0-5-4-2019-04-15"},{"type":"extras","title":"Enhancements - Changelog","doc":"* [X509.RDNSequence] Relax length restriction on `countryName` attribute","ref":"changelog.html#enhancements-6"},{"type":"extras","title":"v0.5.3 (2019-03-14) - Changelog","doc":"","ref":"changelog.html#v0-5-3-2019-03-14"},{"type":"extras","title":"Fixes - Changelog","doc":"* [X509.RDNSequence] Support more attribute types in `to_string/1`","ref":"changelog.html#fixes-10"},{"type":"extras","title":"v0.5.2 (2019-02-21) - Changelog","doc":"","ref":"changelog.html#v0-5-2-2019-02-21"},{"type":"extras","title":"Enhancements - Changelog","doc":"* [X509.Certificate] Add `version/1`, `subject/2` and `issuer/2`\n* [X509.RDNSequence] Add `get_attr/2`","ref":"changelog.html#enhancements-7"},{"type":"extras","title":"v0.5.1 (2019-01-03) - Changelog","doc":"","ref":"changelog.html#v0-5-1-2019-01-03"},{"type":"extras","title":"Fixes - Changelog","doc":"* [X509.Certificate.Validity] The record type returned for GeneralizedTime,\n  used for dates from 2050 forward, was not recognized by OTP, causing\n  certificate creation and encoding to fail (#24)","ref":"changelog.html#fixes-11"},{"type":"extras","title":"v0.5.0 (2018-11-27) - Changelog","doc":"","ref":"changelog.html#v0-5-0-2018-11-27"},{"type":"extras","title":"Enhancements - Changelog","doc":"* [X509.CRL] New module for generating and parsing Certificate Revocation\n    Lists (CRLs)\n  * [X509.CRL.Entry] New module: CRL entries\n  * [X509.CRL.Extension] New module: CRL extensions\n  * [X509.Certificate.Extension] Add support for the CRL Distribution Point\n    extension\n  * [X509.Test.Suite] New module for generating test suites for TLS client\n    testing\n  * [X509.Test.Server] New module: simple server for hosting test suites\n  * Add `x509.gen.suite` Mix task\n  * Add `x509.test_server` Mix task","ref":"changelog.html#enhancements-8"},{"type":"extras","title":"Fixes - Changelog","doc":"* [X509.Certificate.Validity] The `days_from_now/2` function used to\n    calculate the `not_after` timestamp relative to the `not_before` value\n    (including the `backdate_seconds` shift); it is now set relative to the\n    current time","ref":"changelog.html#fixes-12"},{"type":"extras","title":"v0.4.0 (2018-10-19) - Changelog","doc":"","ref":"changelog.html#v0-4-0-2018-10-19"},{"type":"extras","title":"Breaking changes - Changelog","doc":"All `from_der` and `from_pem` functions now return an `:error` tuple on failure\ninstead of `nil`, and wrap their result in a `:ok` tuple in case of success.\nThe only exception is the `from_pem` function in X509, which returns a\n(possibly empty) list.\n\n  * [X509] Removed `to_der/1`, `to_pem/1` and `from_der/2`\n  * [X509.Certificate] Changed the return values of `from_der/1` and\n    `from_pem/1,2`, as described above","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `x509.gen.selfsigned` Mix task\n  * The various `from_pem` and `from_pem!` functions are now more lenient: they\n    scan for the first PEM entry of an appropriate type instead of requiring\n    that it be the only entry\n  * [X509.Certificate] Add `serial/1` to extract a certificate's serial number\n  * [X509.Certificate.Template] The length of randomly generated serial numbers\n    can now be specified using a `{:random, n}` tuple in the `:serial` field,\n    where `n` is the length in bytes; the default is `{:random, 8}`, equivalent\n    to the previous default","ref":"changelog.html#enhancements-9"},{"type":"extras","title":"Fixes - Changelog","doc":"* [X509.Certificate] Fixed the typespec for second parameter of\n    `from_der!/2`, `from_der/2`, `from_pem!/2` and `from_pem/2`\n  * [X509.Certificate] Extract the correct RDN from issuer certificate (#13)\n  * [X509.Certificate.Extensions] `subject_key_identifier/1` returned an AKI\n    record rather than SKI record for ECC keys (#10)\n  * [X509.PublicKey] Documentation: corrected the default value for the\n    `wrap` option for RSA keys in `to_der/1` and `to_pem/1`","ref":"changelog.html#fixes-13"},{"type":"extras","title":"v0.3.0 (2018-09-22) - Changelog","doc":"This release paves the way for some changes in the way PEM and DER\ndecoding works. Eventually there will be six functions in each module, as\nimplemented in `X509.CSR` in this version. The generic functions in the `X509`\nmodule will eventually be removed, with the exception of the`X509.from_pem/2`\nfunction, which returns a (possibly filtered) list of entities found in the\nPEM string.\n\nIn the next version, all `from_der` and `from_pem` functions (except for the\none in `X509`) will return `:ok` / `:error` tuples, so please update existing\ncode to use the new `from_der!` and `from_pem!` functions instead: their return\nvalue on success will always be just the module's primary record type.","ref":"changelog.html#v0-3-0-2018-09-22"},{"type":"extras","title":"Breaking changes - Changelog","doc":"* [X509.Certificate] `from_der/2` and `from_pem/2` now return `nil` in case\n    of failure, for consistency with the current behaviour of other modules;\n    use the new `from_der!/2` and `from_pem!/2` to get the old behaviour of\n    raising an exception","ref":"changelog.html#breaking-changes-1"},{"type":"extras","title":"Enhancements - Changelog","doc":"* [X509.Certificate] Add `from_der!/2` and `from_pem!/2`\n  * [X509.CSR] Add `to_der/1`, `to_pem/1`, `from_der!/1`, `from_der/1`,\n    `from_pem!/1` and `from_pem/1`\n  * [X509.PrivateKey] Add `from_der!/2` and `from_pem!/2`\n  * [X509.PublicKey] Add `from_der!/2` and `from_pem!/2`\n  * Support Elixir v1.7 and ExDoc v0.19","ref":"changelog.html#enhancements-10"},{"type":"extras","title":"Deprecations - Changelog","doc":"The `to_der`, `to_pem` and `from_der` functions in the X509 top-level module\nhave been deprecated. Please use their entity-specific functions in the\nappropriate module instead. The deprecated functions will be removed in an\nupcoming release, prior to v1.0.","ref":"changelog.html#deprecations"},{"type":"extras","title":"v0.2.0 (2018-07-24) - Changelog","doc":"","ref":"changelog.html#v0-2-0-2018-07-24"},{"type":"extras","title":"Breaking changes - Changelog","doc":"* [X509.Certificate] Primary type has been changed from `:Certificate` to `:OTPCertificate`; the `new/[4,5]` and `self_signed/[2,3]` functions now return an `:OTPCertificate` record","ref":"changelog.html#breaking-changes-2"},{"type":"extras","title":"Enhancements - Changelog","doc":"* [X509] `to_der` and `to_pem` now delegate now support `:OTPCertificate` records, by delegating to `X509.Certificate`\n  * [X509.Certificate] Added certificate-specific implementations of `to_der`, `to_pem`, `from_der` and `from_pem`","ref":"changelog.html#enhancements-11"},{"type":"extras","title":"v0.1.0 (2018-07-02) - Changelog","doc":"First public release","ref":"changelog.html#v0-1-0-2018-07-02"},{"type":"extras","title":"X509","doc":"# X509\n\n[![Github.com](https://github.com/voltone/x509/workflows/CI/badge.svg)](https://github.com/voltone/x509/actions)\n[![Hex.pm](https://img.shields.io/hexpm/v/x509.svg)](https://hex.pm/packages/x509)\n[![Hexdocs.pm](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/x509/)\n[![Hex.pm](https://img.shields.io/hexpm/dt/x509.svg)](https://hex.pm/packages/x509)\n[![Hex.pm](https://img.shields.io/hexpm/l/x509.svg)](https://hex.pm/packages/x509)\n[![Github.com](https://img.shields.io/github/last-commit/voltone/x509.svg)](https://github.com/voltone/x509/commits/master)\n\n\nElixir package for working with X.509 certificates, Certificate Signing Requests (CSRs), Certificate Revocation Lists (CRLs) and RSA/ECC key pairs.\n\nRequires Erlang/OTP 20.1 or later.\n\nDevelopment and public release of this package were made possible by\n[Bluecode](https://bluecode.com/).","ref":"readme.html"},{"type":"extras","title":"OTP 28 support - X509","doc":"Due to internal changes in the Erlang/OTP `public_key` application in OTP 28,\nplease beware that:\n\n* When using OTP >= 28, please use OTP 28.0.1 or later; this package is not\n  compatible with the initial OTP 28.0 release (more specifically: it requires\n  `public_key` version 1.18.1, it will not work with 1.18)\n* When compiled with OTP 27 or earlier, this package will not run on OTP 28\n  or later","ref":"readme.html#otp-28-support"},{"type":"extras","title":"Usage - X509","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"As a Certificate Authority (CA) - X509","doc":"Generate a self-signed CA certificate and private key, using the `root_ca`\ntemplate:\n\n```elixir\niex> ca_key = X509.PrivateKey.new_ec(:secp256r1)\n{:ECPrivateKey, ...}\niex> ca = X509.Certificate.self_signed(ca_key,\n...>   \"/C=US/ST=CA/L=San Francisco/O=Acme/CN=ECDSA Root CA\",\n...>   template: :root_ca\n...>)\n{:OTPCertificate, ...}\n```\n\nUse the CA certificate to issue a server certificate, using the default\n`server` template and the given SAN hostnames:\n\n```elixir\niex> my_key = X509.PrivateKey.new_ec(:secp256r1)\n{:ECPrivateKey, ...}\niex> my_cert = my_key |>\n...> X509.PublicKey.derive() |>\n...> X509.Certificate.new(\n...>   \"/C=US/ST=CA/L=San Francisco/O=Acme/CN=Sample\",\n...>   ca, ca_key,\n...>   extensions: [\n...>     subject_alt_name: X509.Certificate.Extension.subject_alt_name([\"example.org\", \"www.example.org\"])\n...>   ]\n...> )\n{:OTPCertificate, ...}\n```\n\nOr sign a certificate based on an incoming CSR:\n\n```elixir\niex> csr = X509.CSR.from_pem!(pem_string)\n{:CertificationRequest, ...}\niex> subject = X509.CSR.subject(csr)\n{:rdnSequence, ...}\niex> my_cert = csr |>\n...> X509.CSR.public_key() |>\n...> X509.Certificate.new(\n...>   subject,\n...>   ca, ca_key,\n...>   extensions: [\n...>     subject_alt_name: X509.Certificate.Extension.subject_alt_name([\"example.org\", \"www.example.org\"])\n...>   ]\n...> )\n```","ref":"readme.html#as-a-certificate-authority-ca"},{"type":"extras","title":"With :public_key for encryption/signing - X509","doc":"Please refer to the documentation for the `X509.PrivateKey` module for\nexamples showing asymmetrical encryption and decryption, as well as message\nsigning and verification, with Erlang/OTP's `:public_key` APIs.","ref":"readme.html#with-public_key-for-encryption-signing"},{"type":"extras","title":"For TLS client/server testing - X509","doc":"The `x509.gen.selfsigned` Mix task generates a self-signed certificate for use\nwith a TLS server in development or testing.\n\nThe `X509.Test.Suite` and `X509.Test.Server` modules may be used to create\ntest cases for TLS clients. The [server_test.exs](test/x509/test/server_test.exs)\nfile can serve as a template: update the `request/2` function to invoke of the\nTLS client under test,  make sure it returns the expected response format, and\nupdate the test server's canned response in the test module's setup if\nnecessary.\n\nYou may want to include the X509 package only in the 'dev' and/or 'test'\nenvironments for this use-case, by adding an `only: ...` clause to the\ndependency definition in your Mix file.","ref":"readme.html#for-tls-client-server-testing"},{"type":"extras","title":"Installation - X509","doc":"Add `x509` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:x509, \"~> 0.9\"}\n  ]\nend\n```\n\nDocumentation can be found at [https://hexdocs.pm/x509](https://hexdocs.pm/x509).","ref":"readme.html#installation"},{"type":"extras","title":"License - X509","doc":"Copyright (c) 2019, Bram Verburg\nAll rights reserved.\n\nRedistribution and use in source and binary forms, with or without\nmodification, are permitted provided that the following conditions are met:\n\n* Redistributions of source code must retain the above copyright notice, this\n  list of conditions and the following disclaimer.\n\n* Redistributions in binary form must reproduce the above copyright notice,\n  this list of conditions and the following disclaimer in the documentation\n  and/or other materials provided with the distribution.\n\n* Neither the name of the copyright holder nor the names of its contributors\n  may be used to endorse or promote products derived from this software\n  without specific prior written permission.\n\nTHIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS \"AS IS\"\nAND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE\nIMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE\nDISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE\nFOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL\nDAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR\nSERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER\nCAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,\nOR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE\nOF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}